/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is the Netscape security libraries.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are 
 * Copyright (C) 1994-2000 Netscape Communications Corporation.  All
 * Rights Reserved.
 * 
 * Contributor(s):
 * 
 * Alternatively, the contents of this file may be used under the
 * terms of the GNU General Public License Version 2 or later (the
 * "GPL"), in which case the provisions of the GPL are applicable 
 * instead of those above.  If you wish to allow use of your 
 * version of this file only under the terms of the GPL and not to
 * allow others to use your version of this file under the MPL,
 * indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by
 * the GPL.  If you do not delete the provisions above, a recipient
 * may use your version of this file under either the MPL or the
 * GPL.
 */
/* @(#)cryptint.h	1.26\t10 Nov 1995 */
/*****************************************************************************
  Definitive Fortezza header file.
  Application Level Interface to Fortezza CI Library.

  Version for CI Library 1.52
    November 8, 1995


  NOTICE: Fortezza Export Policy

    The Fortezza Cryptologic Interface (CI) Library (both source and 
    object) and Fortezza CI Library based applications are defense 
    articles, as defined in the International Traffic In Arms 
    Regulations (ITAR), and are subject to export controls under the 
    ITAR and the Arms Export Control Act. Any export to any country 
    of (a) the Fortezza CI Library, related documentation, and 
    technical data, or (b) your cryptographic application, process, 
    or service that is the direct product of, or contains the 
    Fortezza CI Library must comply with the requirements of the ITAR. 
    If you or your customer intends to engage in such export, contact 
    the United States Department of State, Office of Defense Trade 
    Controls for specific guidance.


 ****************************************************************************/
#ifndef __CRYPTINT_H
#define __CRYPTINT_H

#if __cplusplus__ || __cplusplus
extern "C"
{
#endif /* C++ */

#ifndef PROTO_LIST
#ifdef _K_AND_R_
#define PROTO_LIST(list)  ()
#else
#define PROTO_LIST(list)  list
#endif /*_K_AND_R_ */
#endif /* PROTO_LIST */


#ifndef RETURN_TYPE
#if defined( _WIN32 ) || defined( __WIN32__ )
#define RETURN_TYPE  __declspec(dllimport) int
#elif defined( _WINDOWS ) || defined( _Windows )
#define RETURN_TYPE  extern int _far _pascal
#else
#define RETURN_TYPE  extern int
#endif /* Windows */
#endif /* RETURN_TYPE */

/* MS Visual C++ defines _MSDOS and _WINDOWS    */
/* Borland C/C++ defines __MSDOS__ and _Windows */
#if defined( _WIN32 ) ||  defined ( __WIN32__ )
#define CI_FAR
#elif defined( _WINDOWS ) || defined( _Windows )
#define CI_FAR  _far
#else
#define CI_FAR
#endif /* MS DOS or Windows */


/*****************************************************************************
  Constants
 ****************************************************************************/
#define CI_LIB_VERSION_VAL        0x0152    /* Version 1.52 */

#define CI_CERT_SIZE              2048
#define CI_CERT_FLAGS_SIZE        16
#define CI_CERT_NAME_SIZE         32
#define CI_CHALLENGE_SIZE         20

#define CI_G_SIZE                 128

#define CI_HASHVALUE_SIZE         20

#define CI_IV_SIZE                24

#define CI_KEY_SIZE               12
#define CI_KS_SIZE                10

#define CI_NAME_SIZE              32

#define CI_PASSWORD_SIZE          24
#define CI_PIN_SIZE               12
#define CI_P_SIZE                 128

#define CI_Q_SIZE                 20

#define CI_R_SIZE                 40
#define CI_RANDOM_NO_SIZE         20
#define CI_RANDOM_SEED_SIZE       8
#define CI_RA_SIZE                128
#define CI_RB_SIZE                128
#define CI_REG_FLAGS_SIZE         4

#define CI_S_SIZE                 40
#define CI_SAVE_DATA_SIZE         28
#define CI_SERIAL_NUMBER_SIZE     8
#define CI_SIGNATURE_SIZE         40
#define CI_STATUS_FLAGS_SIZE      4

#define CI_TIME_SIZE              16
#define CI_TIMESTAMP_SIZE         16

#define CI_WRAPPED_X_SIZE         24

#define CI_Y_SIZE                 128

#define CI_X_SIZE                 20


/* Miscellaneous */
#define CI_NULL_FLAG              0 
#define CI_POWER_DOWN_FLAG        2
#define CI_NO_LOG_OFF_FLAG        4
#define CI_INITIATOR_FLAG         0
#define CI_RECIPIENT_FLAG         1

#define CI_BLOCK_LOCK_FLAG        1
#define CI_SSO_LOGGED_ON          0x40
#define CI_USER_LOGGED_ON         0x00
#define CI_FAST_MODE              0x10
#define CI_SLOW_MODE              0x00
#define CI_WORST_CASE_MODE        0x40
#define CI_TYPICAL_CASE_MODE      0x00

/* Card Public Key Algorithms Types */
#define CI_DSA_TYPE               0xA
#define CI_KEA_TYPE               0x5
#define CI_DSA_KEA_TYPE           0xF

/* Fortezza Pin Types */
#define CI_SSO_PIN                0x25
#define CI_USER_PIN               0x2A

/* Crypto Types */
#define CI_ENCRYPT_TYPE           0
#define CI_DECRYPT_TYPE           1
#define CI_HASH_TYPE              2

/* Save and Restore Types */
#define CI_ENCRYPT_INT_TYPE       0x00      /* Internal Encryption */
#define CI_ENCRYPT_EXT_TYPE       0x10      /* External Encryption */
#define CI_DECRYPT_INT_TYPE       0x01      /* Internal Decryption */
#define CI_DECRYPT_EXT_TYPE       0x11      /* External Decryption */
#define CI_HASH_INT_TYPE          0x02      /* Internal Hash */
#define CI_HASH_EXT_TYPE          0x12      /* External Hash */
#define CI_TYPE_EXT_FLAG          0x10      /* Used to differentiate */

/* Configuration types */
#define CI_SET_SPEED_TYPE         1
#define CI_SET_TIMING_TYPE        2

/* Lock States */
#define CI_SOCKET_UNLOCKED        0
#define CI_HOLD_LOCK              1
#define CI_SOCKET_LOCKED          2

/* Fortezza Crypto Types Modes */
#define CI_ECB64_MODE             0
#define CI_CBC64_MODE             1
#define CI_OFB64_MODE             2
#define CI_CFB64_MODE             3
#define CI_CFB32_MODE             4
#define CI_CFB16_MODE             5
#define CI_CFB8_MODE              6

/* Card States */
#define CI_POWER_UP               0
#define CI_UNINITIALIZED          1
#define CI_INITIALIZED            2
#define CI_SSO_INITIALIZED        3
#define CI_LAW_INITIALIZED        4
#define CI_USER_INITIALIZED       5
#define CI_STANDBY                6
#define CI_READY                  7
#define CI_ZEROIZE                8
#define CI_INTERNAL_FAILURE       (-1)

/* Flags for Firmware Update. */
#define CI_NOT_LAST_BLOCK_FLAG    0x00000000UL
#define CI_LAST_BLOCK_FLAG        0x80000000UL
#define CI_DESTRUCTIVE_FLAG       0x000000FFUL
#define CI_NONDESTRUCTIVE_FLAG    0x0000FF00UL


/****************************************************************************
  Fortezza Library Return Codes
 ***************************************************************************/

/* Card Responses */
#define CI_OK                     0
#define CI_FAIL                   1
#define CI_CHECKWORD_FAIL         2
#define CI_INV_TYPE               3
#define CI_INV_MODE               4
#define CI_INV_KEY_INDEX          5
#define CI_INV_CERT_INDEX         6
#define CI_INV_SIZE               7
#define CI_INV_HEADER             8
#define CI_INV_STATE              9
#define CI_EXEC_FAIL              10
#define CI_NO_KEY                 11
#define CI_NO_IV                  12
#define CI_NO_X                   13

#define CI_NO_SAVE                15
#define CI_REG_IN_USE             16
#define CI_INV_COMMAND            17
#define CI_INV_POINTER            18
#define CI_BAD_CLOCK              19
#define CI_NO_DSA_PARMS           20

/* Library Errors */
#define CI_ERROR                  (-1)
#define CI_LIB_NOT_INIT           (-2)
#define CI_CARD_NOT_READY         (-3)
#define CI_CARD_IN_USE            (-4)
#define CI_TIME_OUT               (-5)
#define CI_OUT_OF_MEMORY          (-6)
#define CI_NULL_PTR               (-7)
#define CI_BAD_SIZE               (-8)
#define CI_NO_DECRYPT             (-9)
#define CI_NO_ENCRYPT             (-10)
#define CI_NO_EXECUTE             (-11)
#define CI_BAD_PARAMETER          (-12)
#define CI_OUT_OF_RESOURCES       (-13)

#define CI_NO_CARD                (-20)
#define CI_NO_DRIVER              (-21)
#define CI_NO_CRDSRV              (-22)
#define CI_NO_SCTSRV              (-23)

#define CI_BAD_CARD               (-30)
#define CI_BAD_IOCTL              (-31)
#define CI_BAD_READ               (-32)
#define CI_BAD_SEEK               (-33)
#define CI_BAD_WRITE              (-34)
#define CI_BAD_FLUSH              (-35)
#define CI_BAD_IOSEEK             (-36)
#define CI_BAD_ADDR               (-37)

#define CI_INV_SOCKET_INDEX       (-40)
#define CI_SOCKET_IN_USE          (-41)
#define CI_NO_SOCKET              (-42)
#define CI_SOCKET_NOT_OPENED      (-43)
#define CI_BAD_TUPLES             (-44)
#define CI_NOT_A_CRYPTO_CARD      (-45)

#define CI_INVALID_FUNCTION       (-50)
#define CI_LIB_ALRDY_INIT         (-51)
#define CI_SRVR_ERROR             (-52)


/*****************************************************************************
  Data Structures
 ****************************************************************************/

typedef unsigned char   CI_CERTIFICATE[CI_CERT_SIZE];

typedef unsigned char   CI_CERT_FLAGS[CI_CERT_FLAGS_SIZE];

typedef unsigned char   CI_CERT_STR[CI_CERT_NAME_SIZE+4];

typedef unsigned char   CI_FAR *CI_DATA;

typedef unsigned char   CI_G[CI_G_SIZE];

typedef unsigned char   CI_HASHVALUE[CI_HASHVALUE_SIZE];

typedef unsigned char   CI_IV[CI_IV_SIZE];

typedef unsigned char   CI_KEY[CI_KEY_SIZE];

typedef unsigned char   CI_KS[CI_KS_SIZE];

typedef unsigned char   CI_P[CI_P_SIZE];

typedef unsigned char   CI_PASSWORD[CI_PASSWORD_SIZE + 4];

typedef unsigned char   CI_PIN[CI_PIN_SIZE + 4];

typedef unsigned char   CI_Q[       1
Algorithms Types1DB_PIN[CeT2IVER              (-21)
#define CI_NO_CRDS2_INV_COMMAND2         F_TY1,
    crmfChallengeResp = 2
} CRMFSubseqMess7   SECOidTag  tag2
} CE0#define CI_INV_SIZE              FE0#define CI_INV_SIZE              FE0#dee01    *****************r1D             tOT_eT233)
#define CI_BAD_WRITE              (-342DY         D2define CIF_FAn enumeration for the choices for the Encrypt7  * encoding in des foE0ine CI_NO_SAVE                15
FE0ine CI_NO_SAVE                15
FE0inee01defir   CI_IV[CI_IV_SCI_BAB8hd b)r1   Bnedoc  CI_NO_DSA_PARMS           20

/* LibrargeReIZE               (-7  pubInfo;
      E    E0   20

/* Library Errors */
#defiFE0   20

/* Library Errors */
#defiFE0   e01NVAL     17
#define C2the GPL.  If you do not 4A
} CE0#define CI_INV_ce them with the notice and other p7IT2******************************************2e CI_NO_SCTD2*********F
#d any way.
 *         The most common use is t7    PRArenaPool *st coE0          (-8)
#define CI_NO_DECRFE0          (-8)
#define CI_NO_DECRFE0   e01[CI_      (-5)
#defin2ese enumerated values fo4A   (-42)
#d    (-2typedef unsigned char   CI_CERT_STR[CI_CER2CI_BAD_IOSED2AME_SIZE+F   FEncoderOutputCallback) (void *arg,
					   c7CRMFCertRequest  id *aE0      (-21)
#define CI_NO_CRDSRV FE0      (-21)
#define CI_NO_CRDSRV FE0   e01ef u12)
#define CI_OU2 = 8,
    crmfExtension 4ABAD_Iefine CI_INV_ce them efine CRMF_BYTES_TO_BITS(bytes) ((b7IT2E];

typedef unsigned char   CI_P[CI_P_SIZ2ID_FUNCTIOND2

typedefFATUtionalValidity;
typedef struct CRMFValidityCr7ASN1 must have onuct CE05)
#define CI_BAD_IOSEEK         FE05)
#define CI_BAD_IOSEEK         FE05)
e01Type_CERT_FLAGS_SIZE]c1D**********/

typedTefieT2_INV_COMMAND2         F_TY1,
    crmfChall2***********D2eResp = 2F */f struct CRMFCertReqMessagesStr       CRMFCer7   derInput; /*IfsStr E0            (-44)
#define CI_NOT_FE0            (-44)
#define CI_NOT_FE0   e01    NV_SIZE          01)
#deDECRF   eT2(-342DY         D2define CIF_FAn enumerati2 CI_G[CI_G_D2for the cF0x4t;
typedef struct CRMFPOPOPrivKeyStr         7                 rivKeE0***
  Data Structures
 **********FE0***
  Data Structures
 **********FE0***e018hd   E    E0   20

/R0
FE0ind010ZE                 128

#define C******eT2ubInfo;
      E    E0   20

/* Library Err2PASSWORD_SID2 */
#defiF_TYyStr          CRMFEncryptedKey;
typedef struc7PrivKeyStr {
    Key;
E0 char   CI_FAR *CI_DATA;

typedefFE0 char   CI_FAR *CI_DATA;

typedefFE0 che012***t common use is tR0 you dd0  D2
typed2CTD2*********F
#d any way.
 *         The 2idTag  tag2D2t common FdefProtocolEncrKey;
typedef struct CRMFValidityC7s. */
struct CRMFruct E0
typedef unsigned char   CI_P[CI_FE0
typedef unsigned char   CI_P[CI_FE0
tye01es ft CRMFPOPOPrivKeyNV_SIR fine CI_NO_CRDSRV FE0        18
#defiaIT22AME_SIZE+F   FEncoderOutputCallback) (voi2O_SAVE     D2arg,
				FDECuct CRMFControlStr               CRMFControl;7ding*/
};

struct     E0TY1,
    crmfChallengeResp = 2
} FE0TY1,
    crmfChallengeResp = 2
} FE0TY1e01n 4AB1,
   eT2them efine CRMF_BYTES_TO_BITS(bytes) ((b7I2
#defiFE0  D2];

typedF/*     PRTime *notAfter;
};

struct CRMFCertExtC7b      (2)
			*  tructE0 (-342DY         D2define CIF_FAnFE0 (-342DY         D2define CIF_FAnFE0 (-e01EEK  unsigned char   i0typeubInfo2 FE05)
e01Type_CERT_FLAGS_SIZE]c1D********2e most commD2

typedTeF 2
C_ASN1Template CRMFCertRequestTemplate[];


#7a-1.7.12/nss/crmfestTeE0 20

/* LibrargeReIZE            FE0 20

/* LibrargeReIZE            FE0 20e01    **********r1D    r1DE            ne CI_NO_CRDSRV FE0   e01ef u12)
     YTESst com2eDECRF   eT2(-342DY         D2define CIF_F2 c7CRMFCertD2enumeratiFes sion 1.1 (the "License"); you may not use thi7* 
 * Software diou maE0D2*********F
#d any way.
 *      FE0D2*********F
#d any way.
 *      FE0D2*e01uresSA_PARMS         r1Dway.
 *      tdeeeT20ZE                 128

#define C******eT2ID_FUNCTIOND2Info;
   FfinRANTY OF ANY KIND, either express or
 * impli7Code is the NetscxpresE0STR[CI_CER2CI_BAD_IOSED2AME_SIZE+FE0STR[CI_CER2CI_BAD_IOSED2AME_SIZE+FE0STRe01A;

unsigned char   i     B8hto )r1 C*B01Toc u12)
#define CI_OU2 = 8,
    crmfExtensienseS_SIZE]c1D**********7cations CorporatiSIZE]E0
    crmfExtension 4ABAD_Iefine CFE0
    crmfExtension 4ABAD_Iefine CFE0
  e017s.  id *aE0      (-22struct CRMFOptionalValid4Au maE0D2*********F
#dncryptedvalue_secalg(PRArenaPool   7IT2KeyNV_SIR fine CI_NO_CRDSRV FE0        18
2r the cF0x4D2fiaIT22AMFs *General Public License Version 2 or later (th7 of your 
 * version 2E01D**********/

typedTefieT2_INV_CFE01D**********/

typedTefieT2_INV_CFE01D*e01hallave onuct CE05)
#2ReqMessagesStr       CRM4A is tR0 you2 CI_G2hem efine CRMF_BYTES_TO_BITS(bytes) ((b7I22RD_SID2 */
D2efiFE0  DF   his file under the MPL,
 * indicate your deci7f you do not deleindicE0(-342DY         D2define CIF_FAn FE0(-342DY         D2define CIF_FAn FE0(-3e01FAnF        (-44)
#de2   CRMFPOPOPrivKey;
type4ASID2 *********F
#dncrypted						     PRBool       isCritical,7IT2ate CRMFCertRequestTemplate[];


#7a-1.7.12
struct CRMD2ss/crmfesF   95 */
/**************************************7alues for adding *****E0 Err2PASSWORD_SID2 */
#defiF_TYySFE0 Err2PASSWORD_SID2 */
#defiF_TYySFE0 Ere012)
 Y1e01n 4AB1,
   ec1DMFControl;7ding*/
TTypeT2 c7CRMFCertD2enumeratiFes sion 1.1 (the "L2  CRMFContrD2nse"); yoFineThe Fortezza Cryptologic Interface (CI) Libra7D = 8,
    crmfExterfaE0Tag  tag2D2t common FdefProtocolEFE0Tag  tag2D2t common FdefProtocolEFE0Tage01*   
#d any way.
 *  0      NV_CF_FEeT2**eT2ID_FUNCTIOND2Info;
   FfinRANTY OF AN2
			*  trucD2IND, eithF   under the 
    ITAR and the Arms Export Contr7
    crmfPKIArchi ArmsE0EncoderOutputCallback) (voi2O_SAVFE0EncoderOutputCallback) (voi2O_SAVFE0Ence01 B8htiSIZE]E0
    crmR0+FE0STd010des
 ****************************2O_SAVeT2ions CorporatiSIZE]E0
    crmfExtension 4A2      FE0 2D2_Iefine CF3)
Library must comply with the requirements of 7on;

/*
 * An enue reqE0ime *notAfter;
};

struct CRMFCerFE0ime *notAfter;
};

struct CRMFCerFE0imee01IT2Kon 2 or later (thR0ptionad0OND2s/crmf2x4D2fiaIT22AMFs *General Public License Ve2oftware dioD2on 2 or lFIOS*********************************************7fferent options f*****E0CRMFCertRequestTemplate[];


#7a-FE0CRMFCertRequestTemplate[];


#7a-FE0CRMe01    TAR and the Arms 
#d aR  D2define CIF_FAn FE0(-3SRV FE0      aIT22efiFE0  DF   his file under the MPL,
 * i2ER2CI_BAD_ID2cate yourFPTOndif /* PROTO_LIST */


#ifndef RETURN_TYPE
#7n
 */
typedef enundef E0s sion 1.1 (the "License"); you mFE0s sion 1.1 (the "License"); you mFE0s se01typeBsion 1eT2ypted						     PRBool       isCritical,7I2fine CFE0
 D2te CRMFCeFruc#else
#define RETURN_TYPE  extern int
#endif 7 
 * CRMFPOPOSignexterE0***eT2ID_FUNCTIOND2Info;
   FfinRFE0***eT2ID_FUNCTIOND2Info;
   FfinRFE0***e01*/
#RequestTemplate[]i0hem ions C2SFE0 Ere012)
 Y1e01n 4AB1,
   ec1DMFContro2Version 2 oD2ding*/
TTFE_Selif defined( _WINDOWS ) || defined( _Windows7t = 1,
    crmfCh defiE0   crmfExtensienseS_SIZE]c1D*****FE0   crmfExtensienseS_SIZE]c1D*****FE0   e01 tagS         r1Dway.r1DSIZE]c1D**** 2define CIF_FAn FE0(-3e01FAnF    ZE]c1RBooion 2 2 NV_CF_FEeT2**eT2ID_FUNCTIOND2Info;
   Ffi2ci7f you doD2NTY OF ANFd c_LIB_VERSION_VAL        0x0152    /* Version 7EncryptedKey type152  E0D2fiaIT22AMFs *General Public LicFE0D2fiaIT22AMFs *General Public LicFE0D2fe01llbafine CI_OU2 = 8,
r1Dal Public Li t2*eeT20des
 ****************************2O_SAVeT2
struct CRMD2ns CorporF   LUE_SIZE         20

#define CI_IV_SIZE      7on that the CRMF
e CI_E0es) ((b7I22RD_SID2 */
D2efiFE0  DFE0es) ((b7I22RD_SID2 */
D2efiFE0  DFE0es)e01trucequestTemplate[]i*****B8h0
#)r1**2B012oc F        (-44)
#de2   CRMFPOPOPrivKey;
t    1,
   ec1DMFControl;7ree to use this p
   eE0MFPOPOPrivKey;
type4ASID2 *******FE0MFPOPOPrivKey;
type4ASID2 *******FE0MFPe01**7feindicE0(-342DY  2GPL.
 */
/* @(#)cryptint4A52  E0D2fiaIT22AMFs *FCertReqMsg **messages;
    PRArena7IT2ms 
#d aR  D2define CIF_FAn FE0(-3SRV FE0 2D, eithF   D2  aIT22efFfo;      4

#define CI_S_SIZE                 407llback) (void *ar     E01DMFControl;7ding*/
TTypeT2 c7CRMFE01DMFControl;7ding*/
TTypeT2 c7CRMFE01DMe01the dding *****E0 Err2tologic Interface (CI) L4Ar (thR0ptio2
			*2pted						     PRBool       isCritical,7I22FE0 2D2_IefD2e CFE0
 DF*  PED_X_SIZE         24

#define CI_Y_SIZE     7OptionalValiditySine CE0**eT2ID_FUNCTIOND2Info;
   FfinRAFE0**eT2ID_FUNCTIOND2Info;
   FfinRAFE0**ee01Ffin tag2D2t common F2rol Act. Any export to a4A 2D2_fiaIT22AMFs *FCertReq subjectUID; 
    CRMFCertExtension7IT2d( _WINDOWS ) || defined( _Windows7t = 1,
2nt options D2 crmfCh dFest       1
#define CI_SSO_LOGGED_ON          0x7     CRMFCertReqMGED_OE0n 4A2      FE0 2D2_Iefine CF3)
LiFE0n 4A2      FE0 2D2_Iefine CF3)
LiFE0n 4e01F    se01typeBsion 1ec1DURN_TYPE
#7n
 */
tT2)
eT2ci7f you doD2NTY OF ANFd c_LIB_VERSION_VAL2 RETURN_TYPD2     0x01FefForithms Types */
#define CI_DSA_TYPE         7    CRMFPOPOPrivK_DSA_E0tware dioD2on 2 or lFIOS*********FE0tware dioD2on 2 or lFIOS*********FE0twae01ublis *General Public0UNCTIO7CRMFEFEeT2AVeT2
struct CRMD2ns CorporF   LUE_SIZE   2OPOSignexteD2   20

#dF*D2define CI_ENCRYPT_TYPE           0
#define CI7       CRMFEncryp     E0is file under the MPL,
 * i2ER2CIFE0is file under the MPL,
 * i2ER2CIFE0is e01***B p
   eE0MFPOPOPrR0DFE0esd010V_SCI_BAB8hd b)r1   Bnedoc  CI_NO2ER2CIeT2 to use this p
   eE0MFPOPOPrivKey;
type4A2D*****FE0  D22 *******FMFPYPT_INT_TYPE       0x01      /* Internal Decr7dityCreationInfoS  /* E0define RETURN_TYPE  extern int
#eFE0define RETURN_TYPE  extern int
#eFE0defe01a7IT               40R0@(#)crd0RMD2crmfCh2  D2  aIT22efFfo;      4

#define CI_S_SIZ2edKey type1D2         F */e CI_TYPE_EXT_FLAG          0x10      /* Used7olStr             0x10E0WINDOWS ) || defined( _Windows7t FE0WINDOWS ) || defined( _Windows7t FE0WINe01ce (T_TYPE           s *GeR ND2Info;
   FfinRAFE0**eFAn FE0(-342DaIT22e CFE0
 DF*  PED_X_SIZE         24

#defi2I22RD_SID2 D2CI_Y_SIZEFy;
    2

/* Fortezza Crypto Types Modes */
#def7MFCertExtension *ypes E0 c_LIB_VERSION_VAL        0x0152 FE0 c_LIB_VERSION_VAL        0x0152 FE0 c_e01t toB_LIB_VeT2rtReq subjectUID; 
    CRMFCertExtension7I2******FE0MFD2( _WINDOWFCal_CFB16_MODE             5
#define CI_CFB8_MOD7if /*_CRMFT_H_*/
definE0SAVeT2
struct CRMD2ns CorporF   LFE0SAVeT2
struct CRMD2ns CorporF   LFE0SAVe012_Ie) || defined( _Wii0pted to u